function varargout = analysis(varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:                Analysis
%  Description:          Analyses the result of a simulation and displays
%                                  it in a GUI
%  Dependencies:   analysis.fig                                        
%  Author:                    Stefan Bracher
%  Date:                       14.04.2007
%  Status:                      REL
%  
%  Syntaxe:                  handles=f1m_4lb_6ulb_10agv(handles)
%                                                                    
%  Input:                      varargin:    varargin{1}.t:                          Elapsed simulation time
%                                                      varargin{1}.machine_list:   List of machines
%                                                      varargin{1}.v_work:              The capacity of a machine (units/h)
%                                                      varargin{1}.lbay_list:            Loading bay list
%                                                      varargin{1}.lspeed:              Loading bay capacity (units/h)
%                                                      varargin{1}.ulbay_list:         Unloading bay list
%                                                      varargin{1}.ulspeed:           Unoading bay capacity (units/h)
%                                                      varargin{1}.agv_list:            AGV list
%                                                      varargin{1}.o:       The obstacle map at the end of the simulation
%                                 
%                                                           
%
%%  Output:                   varargout:     Empty
%                                  GUI:               Analysis on screen
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Edit the above text to modify the response to help analysis

% Last Modified by GUIDE v2.5 13-Apr-2007 22:23:21

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @analysis_OpeningFcn, ...
                   'gui_OutputFcn',  @analysis_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before analysis is made visible.
function analysis_OpeningFcn(hObject, eventdata, handles, varargin)
% Opening function of analysis

% Choose default command line output for analysis
handles.output = hObject;

%-----------System information-----------------------
% Simulation time
time=varargin{1}.t;
set(handles.time_output, 'String', time);   % Send to GUI

% Machines
machine_list=varargin{1}.machine_list;
size_machine_list=size(machine_list);                    
machine_n=size_machine_list(1);       
set(handles.machines, 'String', machine_n); % Send to GUI

% Machine Capacity
machine_cap=varargin{1}.v_work*machine_n;
set(handles.machine_cap, 'String', machine_cap); % Send to GUI

% Loading bays
lbay_list=varargin{1}.lbay_list;
size_lbay_list=size(lbay_list);                    
lbay_n=size_lbay_list(1);       
set(handles.lbays, 'String', lbay_n); % Send to GUI

% Loading bays Capacity
lbay_cap=varargin{1}.lspeed*lbay_n;
set(handles.lbay_cap, 'String', lbay_cap); % Send to GUI

% Unloading bays
ulbay_list=varargin{1}.ulbay_list;
size_ulbay_list=size(ulbay_list);                    
ulbay_n=size_ulbay_list(1);       
set(handles.ulbays, 'String', ulbay_n); % Send to GUI

% Unloading bays Capacity
ulbay_cap=varargin{1}.ulspeed*ulbay_n;
set(handles.ulbay_cap, 'String', ulbay_cap); % Send to GUI

% AGVs
agv_list=varargin{1}.agv_list;
size_agv_list=size(agv_list);                    
agv_n=size_agv_list(1);       
set(handles.agvs, 'String', agv_n); % Send to GUI

% Maximal Capacity
max_cap=max([machine_cap, lbay_cap, ulbay_cap]);
set(handles.max_cap, 'String', max_cap);

% Total units treated
units_tot=sum(ulbay_list(:, 4));
set(handles.units_tot, 'String', units_tot);

% Performance
sys_perf=units_tot/(time*max_cap/(60*60))*100;
set(handles.sys_perf, 'String', sys_perf);

% Floormap
axes(handles.obstacles);
imagesc(varargin{1}.o);  
%------------------------------------------------------------------%

%----------Machine information----------------------%
% Idle Time
set(handles.machine_max_idle_time_out, 'String', max(machine_list(:, 5)));
set(handles.machine_min_idle_time_out, 'String', min(machine_list(:, 5)));
set(handles.machine_average_idle_time_out, 'String', mean(machine_list(:, 5)));
 
  % blocked time
set(handles.machine_max_blocked_time_out, 'String', max(machine_list(:, 6)));
set(handles.machine_min_blocked_time_out, 'String', min(machine_list(:, 6)));
set(handles.machine_average_blocked_time_out, 'String', mean(machine_list(:, 6)));

  %peformance
  machine_performance=(time*ones(machine_n, 1)-machine_list(:, 6)-machine_list(:, 5))/time;
  set(handles.machine_max_performance_out, 'String', max(machine_performance)*100);
  set(handles.machine_min_performance_out, 'String', min(machine_performance)*100);
  set(handles.machine_average_performance_out, 'String', mean(machine_performance)*100);

%----------AGV information----------------------%
% Idle Time
set(handles.agv_max_idle_time, 'String', max(agv_list(:, 4)));
set(handles.agv_min_idle_time, 'String', min(agv_list(:, 4)));
set(handles.agv_average_idle_time, 'String', mean(agv_list(:, 4)));

  %peformance
 agv_performance=(time*ones(agv_n, 1)-agv_list(:, 4))/time;
 set(handles.agv_max_performance_out, 'String', max(agv_performance)*100);
 set(handles.agv_min_performance_out, 'String', min(agv_performance)*100);
 set(handles.agv_average_performance_out, 'String', mean(agv_performance)*100);
 
 %----------Loading_Bay information----------------------%
% Idle Time
set(handles.lbay_max_blocked_time_out, 'String', max(lbay_list(:, 4)));
set(handles.lbay_min_blocked_time_out, 'String', min(lbay_list(:, 4)));
set(handles.lbay_average_blocked_time_out, 'String', mean(lbay_list(:, 4)));

  %peformance
 lbay_performance=(time*ones(lbay_n, 1)-lbay_list(:, 4))/time;
 set(handles.lbay_max_performance_out, 'String', max(lbay_performance)*100);
 set(handles.lbay_min_performance_out, 'String', min(lbay_performance)*100);
 set(handles.lbay_average_performance_out, 'String', mean(lbay_performance)*100);
 
 %----------UnLoading_Bay information----------------------%
% Idle Time
set(handles.ulbay_max_idle_time_out, 'String', max(ulbay_list(:, 5)));
set(handles.ulbay_min_idle_time_out, 'String', min(ulbay_list(:, 5)));
set(handles.ulbay_average_idle_time_out, 'String', mean(ulbay_list(:, 5)));

  %peformance
 ulbay_performance=(time*ones(ulbay_n, 1)-ulbay_list(:, 5))/time;
 set(handles.ulbay_max_performance_out, 'String', max(ulbay_performance)*100);
 set(handles.ulbay_min_performance_out, 'String', min(ulbay_performance)*100);
 set(handles.ulbay_average_performance_out, 'String', mean(ulbay_performance)*100);

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes analysis wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = analysis_OutputFcn(hObject, eventdata, handles)
varargout{1} = handles.output;
