%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:                Default Floormap
%  Description:           Builds the shop layout  with:
%                                       2 machines
%                                       1 loading bay
%                                       2 unloading bays
%                                       1 AGV
%                                       some walls
%                                       some doors
%  Dependencies:      none                                             
%  Author:                     Stefan Bracher
%  Date:                        13.04.2007
%  Status:                      REL
%  
%  Syntaxe:                  handles=default_floormap(handles)
%                                                                    
%  Input:                      handles.*.*
%
%
%  Output:                    handles.t:                Elapsed simulation time
%                                   handles.o:              Map of the obstacles:
%                                                                    2D Matrix, 1=0bstacle, 0=no obstacle
%                                   handles.d_i:          Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                  handles.lbay_list:  Loading bay list
%                                                                    n*[x-position, y-position, time_until loaded, blocked time]
%                                                                    n= number of loading bays (details see loading_bay.m)                         
%                                   handles.ulbay_list:  Unloading bay list
%                                                                    n*[x-position, y-position, time_until unloaded, treated units, idle time]
%                                                                    n= number of loading bays (details see uloading_bay.m)                           
%                                   handles.machine_list:  Machine
%                                                                    n*[x-position, y-position, status, time until job completion, idle time, blocked time]
%                                                                    n= number of machines (details see machine.m)                    
%                                   handles.agv_list:  AGV list
 %                                                                  n*[x-position, y-position, status, idle time]
 %                                                                  n=number of AGVs (details see agv.m)   
  %                                  handles.*.*            All the other  unchanged members of handles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function handles=default_floormap(handles)

handles.t=0;                                    % Elapsed simulation time=0

handles.o=zeros(40, 40);             % Making a 40x40 obstacle matrix. 0=free, 1=obstacle

% Put walls
handles.o(1:40 ,1:2)=1;   
handles.o(1:40, 39:40)=1;    
handles.o(1:2, 1:40)=1;
handles.o(39:40, 1:40)=1;
handles.o(25, 1:40)=1;
handles.o(1:40, 20)=1;

% Make doors
handles.o(25, 5:7)=0;
handles.o(25, 35:37)=0;
handles.o(10:12, 20)=0;

% Initiate 40x40 fields for 3 different pheromones
handles.d_i(1:40, 1:40, 1)=zeros(40); 
handles.d_i(1:40, 1:40, 2)=zeros(40);
handles.d_i(1:40, 1:40, 3)=zeros(40);

% Loading bay placement
handles.lbay_list=[];                                    % Clear old placements
handles.lbay_list(1, 1:4)=[31, 6, 0, 0];      % Loading bay 1
handles.o(30:32, 3:5)=1;                             %   Obstruction by Loading bay 1

%Unloading bay placement
handles.ulbay_list=[];                                                          % Clear old placements
handles.ulbay_list(1, 1:5)=[31, 24, 0, 0, 0];     % Unloading bay 1
handles.o(30:32, 21:23)=1;                               % Obstruction by Unloading bay 1
handles.ulbay_list(2, 1:5)=[31, 35, 0, 0, 0];     % Unloading bay 2
handles.o(30:32, 36:38)=1;                                % Obstruction by Unloading bay 2

% Machine placement
handles.machine_list=[];                                        % Clear old placements
handles.machine_list(1, 1:6)=[6, 6, 0, 0, 0, 0];   % Machine 1
handles.o(5:7, 3:5)=1;                                             % Obstruction by Machine 1
handles.machine_list(2, 1:6)=[6, 35, 0, 0, 0, 0];  % Machine 2
handles.o(5:7, 36:38)=1;                                          % Obstruction by Machine 2

% AGV placement
handles.agv_list=[];                                          % Clear old placements
handles.agv_list(1, 1:4)=[35, 10, 1, 0];          % AGV 1, idle





