%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:                   dissipation_2D
%  Description:             Performs a pheromone like dissipation of one timestep of
%                                     the values of a matrice A
%  Dependencies:       none                                             
%  Author:                      Stefan Bracher
%  Date:                         17.03.2007
%  Statut:                       REL
%  
%  Syntaxe:                     A_new=dissipation_2D(A, O, drate, min_v, max_v)
%                                                                    
%  Input:                          A:              A matrix to witch the algorithm has
%                                                       to be applied
%                                      O:             An obstacle matrix.
%                                                       1=Obstacle, 0=free
%                                     drate        Rate of dissapearing of values, 0=continous
%                                     max_v      maximal value
%                                     min_v=0   minimal value
%
%  Output:                        A_new:    The updatet matrix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function A_new=dissipation_2D(A, O, drate, min_v, max_v)

size_A=size(A);                                         % Get the dimensions of the matrix
A_new=A;                                                    % Build the new Matrix, being equal

for x=1:size_A(1)
    for y=1:size_A(2)
    v_gone=0;                                               % Initialisation of the value that left
    myvalue=A(x, y);                                      % The value at coordonates x, y
    v_transfer=myvalue/6;                           % The value to be transferred
	
    % Neigbour #1
    n_x=x+1;                                                     % The neigbours x coordinate
    n_y=y;                                                          % The neigbours y coordinate
    if ((n_x<=size_A(1))&&(n_x>0)&&((n_y<=size_A(2))&&(n_y>0)))
        % if we are still in the matrix
     n_v=A_new(n_x, n_y);                                % The updated value at the neigbours coordonates
	    if (~O(n_x, n_y))                                          % If there is no obstacle at the coordonates
                n_new_v=n_v+v_transfer;                  % Calculate value to transfer
	    	    if (n_new_v>max_v)                            % if maximum value exeeded...
	    		        n_new_v=max_v;                         % reduce to the maximum value
                 end
                 if (n_new_v<min_v)                           % if minimal value exeeded...
                        n_new_v=min_v ;                       % reduce to the maximum value
                 end
                v_gone=v_gone+v_transfer;          % Update the value that left the field
	    		A_new(n_x, n_y)=n_new_v;                        % Transfer the value      
        end
end

 % Neigbour #2
    n_x=x-1;                                                     % The neigbours x coordinate
    n_y=y;                                                          % The neigbours y coordinate
    if ((n_x<=size_A(1))&&(n_x>0)&&((n_y<=size_A(2))&&(n_y>0)))
        % if we are still in the matrix
     n_v=A_new(n_x, n_y);                                % The updated value at the neigbours coordonates
	    if (~O(n_x, n_y))                                          % If there is no obstacle at the coordonates
                n_new_v=n_v+v_transfer;                  % Calculate value to transfer
	    	    if (n_new_v>max_v)                            % if maximum value exeeded...
	    		        n_new_v=max_v;                         % reduce to the maximum value
                 end
                 if (n_new_v<min_v)                           % if minimal value exeeded...
                        n_new_v=min_v ;                       % reduce to the maximum value
                 end
                v_gone=v_gone+v_transfer;          % Update the value that left the field
	    		A_new(n_x, n_y)=n_new_v;                        % Transfer the value      
        end
end

 % Neigbour #3
    n_x=x;                                                     % The neigbours x coordinate
    n_y=y+1;                                                          % The neigbours y coordinate
    if ((n_x<=size_A(1))&&(n_x>0)&&((n_y<=size_A(2))&&(n_y>0)))
        % if we are still in the matrix
     n_v=A_new(n_x, n_y);                                % The updated value at the neigbours coordonates
	    if (~O(n_x, n_y))                                          % If there is no obstacle at the coordonates
                n_new_v=n_v+v_transfer;                  % Calculate value to transfer
	    	    if (n_new_v>max_v)                            % if maximum value exeeded...
	    		        n_new_v=max_v;                         % reduce to the maximum value
                 end
                 if (n_new_v<min_v)                           % if minimal value exeeded...
                        n_new_v=min_v ;                       % reduce to the maximum value
                 end
                v_gone=v_gone+v_transfer;          % Update the value that left the field
	    		A_new(n_x, n_y)=n_new_v;                        % Transfer the value      
        end
end

 % Neigbour #4
    n_x=x;                                                     % The neigbours x coordinate
    n_y=y-1;                                                          % The neigbours y coordinate
    if ((n_x<=size_A(1))&&(n_x>0)&&((n_y<=size_A(2))&&(n_y>0)))
        % if we are still in the matrix
     n_v=A_new(n_x, n_y);                                % The updated value at the neigbours coordonates
	    if (~O(n_x, n_y))                                          % If there is no obstacle at the coordonates
                n_new_v=n_v+v_transfer;                  % Calculate value to transfer
	    	    if (n_new_v>max_v)                            % if maximum value exeeded...
	    		        n_new_v=max_v;                         % reduce to the maximum value
                 end
                 if (n_new_v<min_v)                           % if minimal value exeeded...
                        n_new_v=min_v ;                       % reduce to the maximum value
                 end
                v_gone=v_gone+v_transfer;          % Update the value that left the field
	    		A_new(n_x, n_y)=n_new_v;                        % Transfer the value      
        end
end
			
      
    % The new color of the field itself
   my_new_v=A_new(x, y)-v_gone-A_new(x, y)*drate;  
  
    if (my_new_v>max_v)                            % if maximum value exeeded...
	    		        my_new_v=max_v;                         % reduce to the maximum value
                 end
                 if (my_new_v<min_v)                           % if minimal value exeeded...
                       my_new_v=min_v ;                       % reduce to the maximum value
                 end
   A_new(x, y)=my_new_v;                        % Assign value
    end
end


