%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:                Do step
%  Description:           Does a simulation step of 1 sec
%  Dependencies:     loading_bay.m,  uloading_bay.m,  machine.m,  dissipation_2D.m,   agv.m   
%  Author:                     Stefan Bracher
%  Date:                        10.04.2007
%  Status:                     REL
%  
%  Syntaxe:                
%                                                                    
%  Input:                       handles.t:               Elapsed simulation time
%                                   handles.o:              Map of the obstacles:
%                                                                    2D Matrix, 1=0bstacle, 0=no obstacle
%                                   handles.d_i:          Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                  handles.lbay_list:  Loading bay list
%                                                                    n*[x-position, y-position, time_until loaded, blocked time]
%                                                                    n= number of loading bays (details see loading_bay.m)                         
%                                  handles.ulbay_list:  Unloading bay list
%                                                                    n*[x-position, y-position, time_until unloaded, treated units, idle time]
%                                                                    n= number of loading bays (details see uloading_bay.m)                           
%                                   handles.machine_list:  Machine
%                                                                    n*[x-position, y-position, status, time until job completion, idle time, blocked time]
%                                                                    n= number of machines (details see machine.m)                    
%                                   handles.agv_list:  AGV list
 %                                                                  n*[x-position, y-position, status, idle time]
 %                                                                  n=number of AGVs (details see agv.m)   
 %                                  handles.agv_v:     AGV speed (m/sec)
  %                                  handles.v_diss:   Pheromone dissipation speed (m/sec)
 %                                  handles.*.*            All the other  unchanged members of handles
%
%
%  Output:                     handles.*.*           Updated handles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



function handles=do_step(handles)

handles.t=handles.t+1;            % Simulation time update


for i=1:handles.v_diss              % Depending on the dissipation speed per second do
    
% Loading bay step
[handles.d_i, handles.agv_list, handles.lbay_list]=loading_bay(handles.d_i, handles.agv_list, handles.lbay_list, handles.lspeed, handles.min_v, handles.max_v, handles.v_diss);
% Unoading bay step
[handles.d_i, handles.agv_list, handles.ulbay_list]=uloading_bay(handles.d_i, handles.agv_list, handles.ulbay_list, handles.ulspeed, handles.min_v, handles.max_v, handles.v_diss);
% Machine step
[handles.d_i, handles.agv_list, handles.machine_list]=machine(handles.d_i, handles.agv_list, handles.machine_list, handles.v_work, handles.min_v, handles.max_v, handles.v_diss);

% Dissipation pheromone 1
handles.d_i(1:40, 1:40, 1)=dissipation_2D(handles.d_i(1:40, 1:40, 1), handles.o, handles.drate, handles.min_v, handles.max_v); % Do dissipation
% Dissipation pheromone 2
handles.d_i(1:40, 1:40, 2)=dissipation_2D(handles.d_i(1:40, 1:40, 2), handles.o, handles.drate, handles.min_v, handles.max_v); % Do dissipation
% Dissipation  pheromone 3
handles.d_i(1:40, 1:40, 3)=dissipation_2D(handles.d_i(1:40, 1:40, 3), handles.o, handles.drate, handles.min_v, handles.max_v); % Do dissipation
pause(0)
end

for i=1:handles.agv_v       % Depending on the AGV speed per second do
% AGV step
[handles.o, handles.d_i, handles.agv_list]=agv(handles.o, handles.d_i, handles.agv_list, handles.min_v, handles.max_v, handles.agv_v);
end







