%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:              f1m_4lb_6ulb_10agv
%  Description:           Builds the shop layout  with:
%                                       1 machines
%                                       4 loading bays
%                                       6 unloading bays
%                                       10   AGVs
%                                       some walls
%                                       some doors
%  Dependencies:      none                                             
%  Author:                     Stefan Bracher
%  Date:                        13.04.2007
%  Status:                     REL
%  
%  Syntaxe:                  handles=f1m_4lb_6ulb_10agv(handles)
%                                                                    
%  Input:                       handles.*.*
%
%
%  Output:                    handles.t:                Elapsed simulation time
%                                   handles.o:              Map of the obstacles:
%                                                                    2D Matrix, 1=0bstacle, 0=no obstacle
%                                   handles.d_i:          Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                  handles.lbay_list:  Loading bay list
%                                                                    n*[x-position, y-position, time_until loaded, blocked time]
%                                                                    n= number of loading bays (details see loading_bay.m)                         
%                                   handles.ulbay_list:  Unloading bay list
%                                                                    n*[x-position, y-position, time_until unloaded, treated units, idle time]
%                                                                    n= number of loading bays (details see uloading_bay.m)                           
%                                   handles.machine_list:  Machine
%                                                                    n*[x-position, y-position, status, time until job completion, idle time, blocked time]
%                                                                    n= number of machines (details see machine.m)                    
%                                   handles.agv_list:  AGV list
 %                                                                  n*[x-position, y-position, status, idle time]
 %                                                                  n=number of AGVs (details see agv.m)   
 %                                  handles.*.*            All the other  unchanged members of handles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function handles=f1m_4lb_6ulb_10agv(handles)

handles.t=0;                                    % Elapsed simulation time=0

handles.o=zeros(40, 40);             % Making a 40x40 obstacle matrix. 0=free, 1=obstacle

% Put walls
handles.o(1:40 ,1:2)=1;   
handles.o(1:40, 39:40)=1;    
handles.o(1:2, 1:40)=1;
handles.o(39:40, 1:40)=1;
handles.o(25, 1:40)=1;
handles.o(1:40, 20)=1;

% Make doors
handles.o(25, 5:7)=0;
handles.o(25, 35:37)=0;
handles.o(10:12, 20)=0;

% Initiate 40x40 fields for 3 different pheromones
handles.d_i(1:40, 1:40, 1)=zeros(40); 
handles.d_i(1:40, 1:40, 2)=zeros(40);
handles.d_i(1:40, 1:40, 3)=zeros(40);

% Loading bay placement
handles.lbay_list=[];                                       % Clear old placements
handles.lbay_list(1, 1:4)=[29, 6, 0, 0];         % Loading bay 1
handles.o(28:30, 3:5)=1;                               %   Obstruction by Loading bay 1
handles.lbay_list(2, 1:4)=[33, 6, 0, 0];         % Loading bay 2
handles.o(32:34, 3:5)=1;                               %   Obstruction by Loading bay 2
handles.lbay_list(3, 1:4)=[37, 6, 0, 0];         % Loading bay 3
handles.o(36:38, 3:5)=1;                               %   Obstruction by Loading bay 3
handles.lbay_list(4, 1:4)=[29, 16, 0, 0];       % Loading bay 4
handles.o(28:30, 17:19)=1;                           %   Obstruction by Loading bay 4

%Unloading bay placement
handles.ulbay_list=[];                                            % Clear old placements
handles.ulbay_list(1, 1:5)=[29, 24, 0, 0, 0];     % Unloading bay 1
handles.o(28:30, 21:23)=1;                               % Obstruction by Unloading bay 1
handles.ulbay_list(2, 1:5)=[33, 24, 0, 0, 0];     % Unloading bay 2
handles.o(32:34, 21:23)=1;                                % Obstruction by Unloading bay 2
handles.ulbay_list(3, 1:5)=[37, 24, 0, 0, 0];     % Unloading bay 3
handles.o(36:38, 21:23)=1;                                % Obstruction by Unloading bay 3
handles.ulbay_list(4, 1:5)=[29, 26, 0, 0, 0];     % Unloading bay 4
handles.o(28:30, 27:29)=1;                               % Obstruction by Unloading bay 4
handles.ulbay_list(5, 1:5)=[33, 26, 0, 0, 0];     % Unloading bay 5
handles.o(32:34, 27:29)=1;                                % Obstruction by Unloading bay 5
handles.ulbay_list(6, 1:5)=[37, 26, 0, 0, 0];     % Unloading bay 6

% Machine placement
handles.machine_list=[];                                        % Clear old placements
handles.machine_list(1, 1:6)=[5, 6, 0, 0, 0, 0];   % Machine 1
handles.o(4:6, 3:5)=1;                                             % Obstruction by Machine 1

% AGV placement
handles.agv_list=[];                                          % Clear old placements
handles.agv_list(1, 1:4)=[4, 15, 1, 0];          % AGV 1, idle
handles.agv_list(2, 1:4)=[6, 15, 1, 0];          % AGV 2, idle
handles.agv_list(3, 1:4)=[8, 15, 1, 0];          % AGV 3, idle
handles.agv_list(4, 1:4)=[10, 15, 1, 0];          % AGV 4, idle
handles.agv_list(5, 1:4)=[12, 15, 1, 0];          % AGV 5, idle
handles.agv_list(6, 1:4)=[14, 15, 1, 0];          % AGV 6, idle
handles.agv_list(7, 1:4)=[16, 15, 1, 0];          % AGV 7, idle
handles.agv_list(8, 1:4)=[18, 15, 1, 0];          % AGV 8, idle
handles.agv_list(9, 1:4)=[20, 15, 1, 0];          % AGV 9, idle
handles.agv_list(10, 1:4)=[22, 15, 1, 0];          % AGV 10, idle









