%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Funcion:                    Loading bay
%  Description:             Does one programm step on all Loading bays
%  Dependencies:       none                                             
%  Author:                      Stefan Bracher
%  Date:                         19.03.2007
%  Status:                       REL
%  
%  Syntaxe:                   [d_i, agv_list, lbay_list]=loading_bay(d_i, agv_list, lbay_list, lspeed, min_v, max_v, v_diss)
%                                                                    
%  Input:                          d_i:                       Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                      agv_list:               List of all the agvs. One agv per line.
%                                      lbay_list:              List of all the Loading bays. One bay per line.
%                                                                    [x, y, time until loaded, blocked time]
%                                                                    x, y: Position
%                                                                    time until loaded: Remaining time until part is ready for pick up
%                                                                    blocked time:     Total time spent waiting for pick up
%                                      lspeed:                Time needed to load a part      
 %                                     min_v:                  The minimal pheromone value at a point
 %                                     max_v:                  The maximal pheromone value at a point
  %                                    v_diss:                  Dissipation speed of the pheromone             
%        
%  Output:                       d_i:                        Updated Pheromone maps
%                                      agv_list:                   Updatet AGV list
%                                      lbay_list:                   Updatet lbay list
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [d_i, agv_list, lbay_list]=loading_bay(d_i, agv_list, lbay_list, lspeed, min_v, max_v, v_diss)

size_lbay_list=size(lbay_list);                                     %Determine the number of loading bays
lbay_n=size_lbay_list(1);                                             % Number of loading bays

for i=1:lbay_n                                                              % For all loading bays
    time_until_loaded=lbay_list(i,3);                         % Time until the job is loaded
    bay_x=lbay_list(i,1);                                                       % x-postition
    bay_y=lbay_list(i,2);                                                       % y-postition
   
   
 
     if (time_until_loaded<0)                                               % job ready
         lbay_list(i,4)=lbay_list(i,4)+1/v_diss;                      % Increase blocked time
         d_i(bay_x, bay_y, 1)=d_i(bay_x, bay_y, 1)+10;      % Increase pheromone 1 ("job" waiting pheromone)
        if (d_i(bay_x, bay_y, 1)>max_v)                                 % pheromone overflow protection
            d_i(bay_x, bay_y, 1)=max_v;                                       
        end  
       size_agv=size(agv_list);                                  
        agv_n=size_agv(1);                                                      % Number of agvs
     
        for y=1:agv_n                                                                  % Check if there is an agv ready to pick up the job
          agv_x=agv_list(y,1);
          agv_y=agv_list(y,2);
          agv_status=agv_list(y,3);
          
          if ((agv_x==bay_x)&&(agv_y==bay_y)&&(agv_status==1))     % AGV at bay and ready for pick up
            agv_list(y, 3)=2;                                                                             % Load job on AGV
            time_until_loaded=round(60*60*v_diss/lspeed);                 % Start loading new job   
           end
         end
  
    else  
    time_until_loaded=time_until_loaded-1;              % Decrease time until loaded
    end
 
% Save data
lbay_list(i,3)=time_until_loaded;
end