%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Funcion:                   Machine
%  Description:             Does one programm step on all Machines
%  Dependencies:       none                                             
%  Author:                      Stefan Bracher
%  Date:                         19.03.2007
%  Status:                      REL
%  
%  Syntaxe:                   [d_i, agv_list, machine_list]=machine(d_i, agv_list, machine_list, v_work, min_v, max_v, v_diss)
%                                                                    
%  Input:                          d_i:                       Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                      agv_list:               List of all the agvs. One agv per line.
%                                      machine_list:      List of all Machines. One Machine per line.
%                                                                    [x, y, status, time untill competion, idle time, blocked time]
%                                                                    x, y: Position
%                                                                    status: Machine status: 0=idle, 1= working or done
%                                                                    time until completion: Remaining time until part is ready for pick up
%                                                                    idle time:             Total time spent waiting for a part 
%                                                                    blocked time:     Total time spent waiting for pick up
%                                      v_work:                Time needed finish a part      
 %                                     min_v:                  The minimal pheromone value at a point
 %                                     max_v:                  The maximal pheromone value at a point
 %                                    v_diss:                  Dissipation speed of the pheromone       
%        
%  Output:                    d_i:                            Updated Pheromone maps
%                                   agv_list:                   Updatet AGV list
%                                  machine_list:           Updatet Machine list
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [d_i, agv_list, machine_list]=machine(d_i, agv_list, machine_list, v_work, min_v, max_v, v_diss)

size_machine_list=size(machine_list);                                  %Determine the number of loading bays
machine_n=size_machine_list(1);                                          % Number of loading bays

for i=1:machine_n                                                                       % For all loading bays
    time_until_done=machine_list(i,4);                                     % Time until the job is loaded
    m_x=machine_list(i,1);                                                           % x-postition
    m_y=machine_list(i,2);                                                           % y-postition
    busy=machine_list(i,3);                                                          % status of the machine
   
 
 % Machine Idle: Ready to take a job
     if (busy==0)                                                                               % machine idle
         machine_list(i, 5)=machine_list(i, 5)+1/v_diss;            % Increase Idle time
         d_i(m_x, m_y, 2)=d_i(m_x, m_y, 2)+10;                          % Increase pheromone 2 ('ready to take a job')
        if (d_i(m_x, m_y, 2)>max_v)                                               % pheromone overflow protection
            d_i(m_x, m_y, 2)=max_v;                                       
        end  
        
       size_agv=size(agv_list);                                  
        agv_n=size_agv(1);                                                              % Number of agvs
     
        for y=1:agv_n                                                                         % Check if there is an agv who wants to deliver a job
          agv_x=agv_list(y,1);
          agv_y=agv_list(y,2);
          agv_status=agv_list(y,3);
          
          if ((agv_x==m_x)&&(agv_y==m_y)&&(agv_status==2))       % AGV at machine and delivering
           
            agv_list(y, 3)=1;                                                                          % AGV empty again
            time_until_done=round(60*60*v_diss/v_work);                   % Start loading new job
            busy=1;
           end
         end
    end
    
    % Machine Working or done
     if ((time_until_done<0)&&(busy==1))                                 % machine did job (machine blocked)
       machine_list(i, 6)= machine_list(i, 6)+1/v_diss;            % Increase blocked time
         d_i(m_x, m_y, 1)=d_i(m_x, m_y, 1)+10;                         % Increase pheromone 1 ('something to deliver')
        if (d_i(m_x, m_y, 1)>max_v)                                               % pheromone overflow protection
            d_i(m_x, m_y, 1)=max_v;                                       
        end  
       size_agv=size(agv_list);                                  
        agv_n=size_agv(1);                                                              % Number of agvs
     
        for y=1:agv_n                                                                         % Check if there is an agv ready to pick up the job
          agv_x=agv_list(y,1);
          agv_y=agv_list(y,2);
          agv_status=agv_list(y,3);
          
          if ((agv_x==m_x)&&(agv_y==m_y)&&(agv_status==1)) % AGV at bay and ready to pick up
            agv_list(y, 3)=3;                                                                   % AGV loaded with finished job
            busy=0;                                                                                 % Machine ready to take a new job          
           end
         end
     else  
    time_until_done=time_until_done-1;                                      % Decrease time until done
    end
 
% Save data
machine_list(i,4)=time_until_done;
machine_list(i,3)=busy;
end