function varargout = main(varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:               Main function
%  Description:         GUI callback organisation for the simulation
%  Dependencies:   main.fig, floormaps,   analysis.m, do_step.m                                
%  Author:                    Stefan Bracher
%  Date:                       14.04.2007
%  Status:                      REL
%  
%  Syntaxe:                  varargout = main(varargin)
%                                                                    
%  Input:                      varargin:  Empty
%                                 
%                                                           
%
%%  Output:               varargout:     Empty
%                                  GUI:               Analysis on screen
%                                   video.avi      File in the folder (if video option is selected) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Edit the above text to modify the response to help main

% Last Modified by GUIDE v2.5 14-Apr-2007 23:49:44

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @main_OpeningFcn, ...
                   'gui_OutputFcn',  @main_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before main is made visible.
function main_OpeningFcn(hObject, eventdata, handles, varargin)
% Opening function
% Choose default command line output for main
handles.output = hObject;

% My Parameter initiation
handles.t=0;                    % Simulation time=0
handles.stop=0;             % Don't interrupt any loops
handles.message='Hello: To see how I work, read the readme file in my main folder or just try me out.';
handles.graphics=0;    % Graphics turned off per default
handles.video=0;           % Video off per default
handles.v_diss=10;      % Default dissipation speed
handles.drate=0.01;      % Rate of destruction of pheromone (mass continuum: drate=0)
handles.min_v=0;          % Minimal value of pheromones at a place
handles.max_v=255;    % Maximum values of pheromones at a place
handles.agv_v=1;          % AGV Speed
handles.lspeed=30;      % Loading speed (units/h)
handles.v_work=30;      % Working speed machine (units/h)
handles.ulspeed=30;    % Unloading speed (units/h)

% Load default floormap
handles=default_floormap(handles);
handles.message='Default floormap is loaded.';

handles=update_screen(handles);         % Update screen
guidata(hObject, handles);                         % Update handles structure

% UIWAIT makes main wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = main_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function popupmenu1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in popupmenu1.
function popupmenu1_Callback(hObject, eventdata, handles)
% Popupmenu for layout selection
handles=guidata(gcbo);           % Get the guidata
val = get(hObject,'Value');         % Returns the number of the selected item
str = get(hObject, 'String');        % Returns possible items
switch str{val};                             % Different codes to excecute depending on selection
case 'default'   
   handles=default_floormap(handles);
   handles.message='Default floormap is loaded.';
   out=handles.lbay_list
 case 'richman' 
   handles=richmans_floormap(handles);
   handles.message='Richmans floormap is loaded.';
    case 'optimized' 
   handles=optimized_floormap(handles);
   handles.message='optimizes.';
   %---------------------------------------------------------------------
  case '10m_4lb_6ulb_10agv' 
   handles=f10m_4lb_6ulb_10agv(handles);
   handles.message='10m_4lb_6ulb_10agv floormap is loaded.';
     case '8m_4lb_6ulb_10agv' 
   handles=f8m_4lb_6ulb_10agv(handles);
   handles.message='8m_4lb_6ulb_10agv floormap is loaded.';
     case '6m_4lb_6ulb_10agv' 
   handles=f6m_4lb_6ulb_10agv(handles);
   handles.message='6m_4lb_6ulb_10agv floormap is loaded.';
     case '4m_4lb_6ulb_10agv' 
   handles=f4m_4lb_6ulb_10agv(handles);
   handles.message='4m_4lb_6ulb_10agv floormap is loaded.';
     case '2m_4lb_6ulb_10agv' 
   handles=f2m_4lb_6ulb_10agv(handles);
   handles.message='2m_4lb_6ulb_10agv floormap is loaded.';
     case '1m_4lb_6ulb_10agv' 
   handles=f1m_4lb_6ulb_10agv(handles);
   handles.message='1m_4lb_6ulb_10agv floormap is loaded.';
     %---------------------------------------------------------------------
        case '5m_1lb_6ulb_10agv' 
   handles=f5m_1lb_6ulb_10agv(handles);
   handles.message='5m_1lb_6ulb_10agv floormap is loaded.';
          case '5m_2lb_6ulb_10agv' 
   handles=f5m_2lb_6ulb_10agv(handles);
   handles.message='5m_2lb_6ulb_10agv floormap is loaded.';
          case '5m_4lb_6ulb_10agv' 
   handles=f5m_4lb_6ulb_10agv(handles);
   handles.message='5m_4lb_6ulb_10agv floormap is loaded.';
          case '5m_6lb_6ulb_10agv' 
   handles=f5m_6lb_6ulb_10agv(handles);
   handles.message='5m_6lb_6ulb_10agv floormap is loaded.';
          case '5m_8lb_6ulb_10agv' 
   handles=f5m_8lb_6ulb_10agv(handles);
   handles.message='5m_8lb_6ulb_10agv floormap is loaded.';
          case '5m_10lb_6ulb_10agv' 
   handles=f5m_10lb_6ulb_10agv(handles);
   handles.message='5m_10lb_6ulb_10agv floormap is loaded.';
          case '5m_12lb_6ulb_10agv' 
   handles=f5m_12lb_6ulb_10agv(handles);
   handles.message='5m_12lb_6ulb_10agv floormap is loaded.';
   %---------------------------------------------------------------------
              case '5m_4lb_1ulb_10agv' 
   handles=f5m_4lb_1ulb_10agv(handles);
   handles.message='5m_4lb_1ulb_10agv floormap is loaded.';
                 case '5m_4lb_2ulb_10agv' 
   handles=f5m_4lb_2ulb_10agv(handles);
   handles.message='5m_4lb_2ulb_10agv floormap is loaded.';
                 case '5m_4lb_4ulb_10agv' 
   handles=f5m_4lb_4ulb_10agv(handles);
   handles.message='5m_4lb_4ulb_10agv floormap is loaded.';
                 case '5m_4lb_6ulb_10agv' 
   handles=f5m_4lb_6ulb_10agv(handles);
   handles.message='5m_4lb_6ulb_10agv floormap is loaded.';
                 case '5m_4lb_8ulb_10agv' 
   handles=f5m_4lb_8ulb_10agv(handles);
   handles.message='5m_4lb_8ulb_10agv floormap is loaded.';
                 case '5m_4lb_10ulb_10agv' 
   handles=f5m_4lb_10ulb_10agv(handles);
   handles.message='5m_4lb_10ulb_10agv floormap is loaded.';
                 case '5m_4lb_12ulb_10agv' 
   handles=f5m_4lb_12ulb_10agv(handles);
   handles.message='5m_4lb_12ulb_10agv floormap is loaded.';
      %---------------------------------------------------------------------
               case '5m_4lb_6ulb_1agv' 
   handles=f5m_4lb_6ulb_1agv(handles);
   handles.message='5m_4lb_6ulb_1agv floormap is loaded.';
       case '5m_4lb_6ulb_2agv' 
   handles=f5m_4lb_6ulb_2agv(handles);
   handles.message='5m_4lb_6ulb_2agv floormap is loaded.';
       case '5m_4lb_6ulb_4agv' 
   handles=f5m_4lb_6ulb_4agv(handles);
   handles.message='5m_4lb_6ulb_4agv floormap is loaded.';
       case '5m_4lb_6ulb_8agv' 
   handles=f5m_4lb_6ulb_8agv(handles);
   handles.message='5m_4lb_6ulb_8agv floormap is loaded.';
       case '5m_4lb_6ulb_12agv' 
   handles=f5m_4lb_6ulb_12agv(handles);
   handles.message='5m_4lb_6ulb_12agv floormap is loaded.';
       case '5m_4lb_6ulb_16agv' 
   handles=f5m_4lb_6ulb_16agv(handles);
   handles.message='5m_4lb_6ulb_16agv floormap is loaded.';
       case '5m_4lb_6ulb_20agv' 
   handles=f5m_4lb_6ulb_20agv(handles);
   handles.message='5m_4lb_6ulb_20agv floormap is loaded.';
         %---------------------------------------------------------------------
     case 'many doors' 
   handles=f_many_doors(handles);
   handles.message='many doors (5m_4lb_6ulb_10agv) floormap is loaded.';
        case 'no walls' 
   handles=f_no_walls(handles);
   handles.message='no walls (5m_4lb_6ulb_10agv) floormap is loaded.';
          case 'paths' 
   handles=f_paths(handles);
   handles.message='paths (5m_4lb_6ulb_10agv) floormap is loaded.';
          case 'circular arrangement' 
   handles=f_circular_arrangement(handles);
   handles.message='circular arrangement (5m_4lb_6ulb_10agv) floormap is loaded.';
            case 'close circular arrangement' 
   handles=f_close_circular_arrangement(handles);
   handles.message='close circular arrangement (5m_4lb_6ulb_10agv) floormap is loaded.';
            case 'circular path' 
   handles=f_circular_path(handles);
   handles.message='circular path (5m_4lb_6ulb_10agv) floormap is loaded.';
end
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure



% --- Executes on button press in run_forever.
function run_forever_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.stop=0;                         % Enable 24h run
handles.message='Continous run: The simulation will run until the "Stop"-Button is pressed.';
guidata(gcbo, handles);          % save changes to structure

while (handles.stop==0)
    if (handles.graphics==1)
        pause(0.2);
    else
        pause(0);
    end
    
handles=guidata(gcbo);          % Get the guidata
handles=do_step(handles);   % Do a step
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure
end

% --- Executes on button press in stop_button.
function stop_button_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.stop=1;                        % Stop any ongoing excecution
handles.message='Simulation stopped.';
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure



% --- Executes on button press in Reset_button.
function Reset_button_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.t=0;                               % Simulation time=0
handles.message='Time reinitialisated.';
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure


% --- Executes on button press in analyse_button.
function analyse_button_Callback(hObject, eventdata, handles)
analysis(handles);      % Open the analysis window


% --- Executes on button press in run_one_step.
function run_one_step_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles=do_step(handles);   % Do a step
handles.message='One timestep (1 sec) excecuted.';
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure

 

% --- Executes on button press in run6h.
function run6h_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.stop=0;                         % Enable 24h run
handles.message='The simulation will run until 6h elapsed. To pause or stop, just press the "Stop"-Button at any time.';
guidata(gcbo, handles);          % save changes to structure

while ((handles.t<(60*60*6))&&(handles.stop==0))
    if (handles.graphics==1)       % Allow interruptility
        pause(0.2);
    else
        pause(0);
    end
handles=guidata(gcbo);          % Get the guidata
handles=do_step(handles);   % Do a step
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure
end


% --- Executes on button press in configurate.
function configurate_Callback(hObject, eventdata, handles)

% --- Executes on Graphics on selected
function graphics_on_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
if (get(hObject,'Value') == get(hObject,'Max'))
handles.graphics=1;
handles.message='Graphics turned on (Slower excecution).';
else
handles.graphics=0;
handles.message='Graphics turned off (Faster excecution).';
end
handles=update_screen(handles);         % Update screen
guidata(gcbo, handles);          % save changes to structure

% Hint: get(hObject,'Value') returns toggle state of graphics_on


% --- Executes during object creation, after setting all properties.
function drate_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to drate_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function drate_input_Callback(hObject, eventdata, handles)
% Change the dissipation rate
handles=guidata(gcbo);          % Get the guidata
handles.drate=str2double(get(hObject,'String'))/handles.v_diss;   % Get and set the value
handles.message='Dissipation rate updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle



% --- Executes during object creation, after setting all properties.
function max_v_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to max_v_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function max_v_input_Callback(hObject, eventdata, handles)
% Change the maximal pheromone concentration
handles=guidata(gcbo);          % Get the guidata
handles.max_v=str2double(get(hObject,'String'));   % Get and set the value
handles.message='Maximal pheromone concentration updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle


% --- Executes during object creation, after setting all properties.
function min_v_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to min_v_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function min_v_input_Callback(hObject, eventdata, handles)
% Change the minimal pheromone concentration
handles=guidata(gcbo);          % Get the guidata
handles.min_v=str2double(get(hObject,'String'));   % Get and set the value
handles.message='Minimal pheromone concentration updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle


% --- Executes during object creation, after setting all properties.
function diss_v_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to diss_v_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function diss_v_input_Callback(hObject, eventdata, handles)
% Change the dissipation speed
handles=guidata(gcbo);          % Get the guidata
handles.v_diss=str2double(get(hObject,'String'));   % Get and set the value
handles.message='Dissipation speed updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle



% --- Executes during object creation, after setting all properties.
function agv_v_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to agv_v_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function agv_v_input_Callback(hObject, eventdata, handles)
% Change the AGV speed
handles=guidata(gcbo);          % Get the guidata
handles.agv_v=str2double(get(hObject,'String'));   % Get and set the value
handles.message='AGV speed updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle


% --- Executes during object creation, after setting all properties.
function lspeed_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to lspeed_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function lspeed_input_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.lspeed=str2double(get(hObject,'String'));   % Get and set the value
handles.message='Loading speed updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle


% --- Executes during object creation, after setting all properties.
function ulspeed_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ulspeed_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function ulspeed_input_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.ulspeed=str2double(get(hObject,'String'));   % Get and set the value
handles.message='Unloading speed updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle


% --- Executes during object creation, after setting all properties.
function v_work_input_CreateFcn(hObject, eventdata, handles)
% hObject    handle to v_work_input (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function v_work_input_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.v_work=str2double(get(hObject,'String'));   % Get and set the value
handles.message='Loading speed updated.';   % Set a message
handles=update_screen(handles);                                              % Update screen
guidata(gcbo, handles);                                                 % save changes to handle


% --- Executes on button press in save_video.
function save_video_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
if (get(hObject,'Value') == get(hObject,'Max'))
handles.video=1;
handles.message='Saving frames to video (Watch memory!!!!!!)';
else
handles.video=0;
handles.message='Video turned off.';
end
handles=update_screen(handles);         % Update screen
update_screen(handles)
guidata(gcbo, handles);                                                 % save changes to handle

% --- Executes on button press in make_videofile.
function make_videofile_Callback(hObject, eventdata, handles)
handles=guidata(gcbo);          % Get the guidata
handles.message='Saving video to file. This may take some time...)';
handles=update_screen(handles);         % Update screen
movie2avi(handles.film, 'video');           % Merge Film to a "video.avi".
clear handles.film;                         % delete the frames
guidata(gcbo, handles);          % save changes to structure
% hObject    handle to make_videofile (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


