%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Funcion:                   Unoading bay
%  Description:             Does one programm step on all Unloading bays
%  Dependencies:       none                                             
%  Author:                      Stefan Bracher
%  Date:                         19.03.2007
%  Status:                       REL
%  
%  Syntaxe:                   function [d_i, agv_list, ulbay_list]=uloading_bay(d_i, agv_list, ulbay_list, ulspeed, min_v, max_v, v_diss)
%                                                                    
%  Input:                          d_i:                       Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                      agv_list:               List of all the agvs. One agv per line.
%                                      ulbay_list:             List of all the Unloading bays. One bay per line.
%                                                                    [x, y, time until unloaded, units treatd]
%                                                                    x, y: Position
%                                                                    time until unloaded: Remaining time until part is unloaded
%                                                                    units treated:     Total number of units unloaded during simulation
%                                                                    idle time:     Total time spent waiting for delivery
%                                      ulspeed:                Time needed to unload a part      
 %                                     min_v:                  The minimal pheromone value at a point
 %                                     max_v:                  The maximal pheromone value at a point
  %                                    v_diss:                  Dissipation speed of the pheromone             
%        
%  Output:                       d_i:                        Updated Pheromone maps
%                                      agv_list:                Updatet AGV list
%                                      ulbay_list:             Updatet ulbay list
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [d_i, agv_list, ulbay_list]=uloading_bay(d_i, agv_list, ulbay_list, ulspeed, min_v, max_v, v_diss)

size_ulbay_list=size(ulbay_list);                                  %Determine the number of unloading bays
ulbay_n=size_ulbay_list(1);                                          % Number of unloading bays

for i=1:ulbay_n                                                                 % For all unloading bays
    time_until_unloaded=ulbay_list(i,3);                       % Time until the job is unloaded
    bay_x=ulbay_list(i,1);                                                  % x-postition
    bay_y=ulbay_list(i,2);                                                  % y-postition
   
   
 
     if (time_until_unloaded<0)                                         %ready
         d_i(bay_x, bay_y, 3)=d_i(bay_x, bay_y, 3)+10;    % Increase pheromone 3 (ready to take finished item)
        if (d_i(bay_x, bay_y, 3)>max_v)                               % pheromone overflow protection
            d_i(bay_x, bay_y, 3)=max_v;                                       
        end  
      
        ulbay_list(i, 5)=ulbay_list(i, 5)+1/v_diss;                % Add idle time
        size_agv=size(agv_list);                                  
        agv_n=size_agv(1);                                                    % Number of agvs
     
        for y=1:agv_n                                                               % Check if there is an agv ready to bring a job
          agv_x=agv_list(y,1);
          agv_y=agv_list(y,2);
          agv_status=agv_list(y,3);
          
          if ((agv_x==bay_x)&&(agv_y==bay_y)&&(agv_status==3))       % AGV at bay and ready to deliver
           
            agv_list(y, 3)=1;                                                       % Unload the agv
            ulbay_list(i, 4)=ulbay_list(i, 4)+1;                         % Add a unit to do done units
            time_until_unloaded=round(60*60*v_diss/ulspeed);   % Start unloading
           end
         end
     
     
    else  
    time_until_unloaded=time_until_unloaded-1;          % decrease time until unloaded
    end
 
% Save data
ulbay_list(i,3)=time_until_unloaded;
end