%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:                Update screen
%  Description:           Updates the GUI
%  Dependencies:     main.fig
%  Author:                     Stefan Bracher
%  Date:                        14.03.2007
%  Status:                     REL
%  
%  Syntaxe:                 handles=update_screen(handles)
%                                                                    
%  Input:                       handles.t:               Elapsed simulation time
%                                   handles.o:              Map of the obstacles:
%                                                                    2D Matrix, 1=0bstacle, 0=no obstacle
%                                   handles.d_i:          Pheromone maps
%                                                                   (2+n)D Matrix, n=number of different pheromones
%                                  handles.lbay_list:  Loading bay list
%                                                                    n*[x-position, y-position, time_until loaded, blocked time]
%                                                                    n= number of loading bays (details see loading_bay.m)                         
%                                  handles.ulbay_list:  Unloading bay list
%                                                                    n*[x-position, y-position, time_until unloaded, treated units, idle time]
%                                                                    n= number of loading bays (details see uloading_bay.m)                           
%                                   handles.machine_list:  Machine
%                                                                    n*[x-position, y-position, status, time until job completion, idle time, blocked time]
%                                                                    n= number of machines (details see machine.m)                    
%                                   handles.agv_list:  AGV list
 %                                                                  n*[x-position, y-position, status, idle time]
 %                                                                  n=number of AGVs (details see agv.m)   
 %                                  handles.agv_v:     AGV speed (m/sec)
  %                                  handles.v_diss:   Pheromone dissipation speed (m/sec)
 %                                  handles.*.*            All the other  unchanged members of handles
 %                                  handles.film:         Video frames
%
%
%  Output:                    handles.*.*           Updated handles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function handles=update_screen(handles)

% Update the time
h=floor(handles.t/(60*60));
min=floor((handles.t-h*60*60)/60);
sec=handles.t-h*60*60-min*60;
set(handles.time_sec, 'String', num2str(sec));
set(handles.time_min, 'String', num2str(min));
set(handles.time_h, 'String', num2str(h));

%Update parameters
set(handles.drate_input, 'String', num2str(handles.drate));
set(handles.max_v_input, 'String', num2str(handles.max_v));
set(handles.min_v_input, 'String', num2str(handles.min_v));
set(handles.diss_v_input, 'String', num2str(handles.v_diss));
set(handles.lspeed_input, 'String', num2str(handles.lspeed));
set(handles.ulspeed_input, 'String', num2str(handles.ulspeed));
set(handles.v_work_input, 'String', num2str(handles.v_work));

% Update the message
set(handles.output_message, 'String', handles.message);

if (handles.graphics==1)            % If graphics turned on
% Print the figures
axes(handles.floor_map);
set(gcf,'DoubleBuffer','on');
imagesc(handles.o);  

if (handles.video==1)                 % If video shooting is on
handles.film(handles.t+1) = getframe;            % Save frame to film
end

axes(handles.pheromone_job_waiting);
caxis([handles.min_v handles.max_v])                     
colormap(jet)
image(handles.d_i(1:40, 1:40, 1))
axes(handles.pheromone_idle);
image(handles.d_i(1:40, 1:40, 2))
axes(handles.pheromone_unload);
image(handles.d_i(1:40, 1:40, 3))  
end

